TestDummyRng

Struct TestDummyRng 

pub struct TestDummyRng;
A dummy implementation of RandomGenerator for testing purposes. This struct is used when methods are called via the RandomGenerator trait without directly interacting with self.rng. This is for testing only, see several examples in the operators module